==> aws-cdk-lib-2.225.0-sources.jar: software/amazon/awscdk/interfaces/ses/MailManagerIngressPointReference.java <==
package software.amazon.awscdk.interfaces.ses;

/**
 * A reference to a MailManagerIngressPoint resource.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.interfaces.ses.*;
 * MailManagerIngressPointReference mailManagerIngressPointReference = MailManagerIngressPointReference.builder()
 *         .ingressPointId("ingressPointId")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.119.0 (build 1634eac)", date = "2025-11-17T14:41:04.001Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.interfaces.aws_ses.MailManagerIngressPointReference")
@software.amazon.jsii.Jsii.Proxy(MailManagerIngressPointReference.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface MailManagerIngressPointReference extends software.amazon.jsii.JsiiSerializable {

    /**
     * The IngressPointId of the MailManagerIngressPoint resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getIngressPointId();

    /**
     * @return a {@link Builder} of {@link MailManagerIngressPointReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MailManagerIngressPointReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<MailManagerIngressPointReference> {
        java.lang.String ingressPointId;

        /**
         * Sets the value of {@link MailManagerIngressPointReference#getIngressPointId}
         * @param ingressPointId The IngressPointId of the MailManagerIngressPoint resource. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder ingressPointId(java.lang.String ingressPointId) {
            this.ingressPointId = ingressPointId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MailManagerIngressPointReference}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public MailManagerIngressPointReference build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link MailManagerIngressPointReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MailManagerIngressPointReference {
        private final java.lang.String ingressPointId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.ingressPointId = software.amazon.jsii.Kernel.get(this, "ingressPointId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.ingressPointId = java.util.Objects.requireNonNull(builder.ingressPointId, "ingressPointId is required");
        }

        @Override
        public final java.lang.String getIngressPointId() {
            return this.ingressPointId;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("ingressPointId", om.valueToTree(this.getIngressPointId()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.interfaces.aws_ses.MailManagerIngressPointReference"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MailManagerIngressPointReference.Jsii$Proxy that = (MailManagerIngressPointReference.Jsii$Proxy) o;

            return this.ingressPointId.equals(that.ingressPointId);
        }

        @Override
        public final int hashCode() {
            int result = this.ingressPointId.hashCode();
            return result;
        }
    }
}

==> aws-cdk-lib-2.231.0-sources.jar: software/amazon/awscdk/interfaces/ses/MailManagerIngressPointReference.java <==
package software.amazon.awscdk.interfaces.ses;

/**
 * A reference to a MailManagerIngressPoint resource.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.interfaces.ses.*;
 * MailManagerIngressPointReference mailManagerIngressPointReference = MailManagerIngressPointReference.builder()
 *         .ingressPointArn("ingressPointArn")
 *         .ingressPointId("ingressPointId")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.119.0 (build 1634eac)", date = "2025-12-01T16:02:33.210Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.interfaces.aws_ses.MailManagerIngressPointReference")
@software.amazon.jsii.Jsii.Proxy(MailManagerIngressPointReference.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface MailManagerIngressPointReference extends software.amazon.jsii.JsiiSerializable {

    /**
     * The ARN of the MailManagerIngressPoint resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getIngressPointArn();

    /**
     * The IngressPointId of the MailManagerIngressPoint resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getIngressPointId();

    /**
     * @return a {@link Builder} of {@link MailManagerIngressPointReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MailManagerIngressPointReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<MailManagerIngressPointReference> {
        java.lang.String ingressPointArn;
        java.lang.String ingressPointId;

        /**
         * Sets the value of {@link MailManagerIngressPointReference#getIngressPointArn}
         * @param ingressPointArn The ARN of the MailManagerIngressPoint resource. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder ingressPointArn(java.lang.String ingressPointArn) {
            this.ingressPointArn = ingressPointArn;
            return this;
        }

        /**
         * Sets the value of {@link MailManagerIngressPointReference#getIngressPointId}
         * @param ingressPointId The IngressPointId of the MailManagerIngressPoint resource. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder ingressPointId(java.lang.String ingressPointId) {
            this.ingressPointId = ingressPointId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MailManagerIngressPointReference}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public MailManagerIngressPointReference build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link MailManagerIngressPointReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MailManagerIngressPointReference {
        private final java.lang.String ingressPointArn;
        private final java.lang.String ingressPointId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.ingressPointArn = software.amazon.jsii.Kernel.get(this, "ingressPointArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.ingressPointId = software.amazon.jsii.Kernel.get(this, "ingressPointId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.ingressPointArn = java.util.Objects.requireNonNull(builder.ingressPointArn, "ingressPointArn is required");
            this.ingressPointId = java.util.Objects.requireNonNull(builder.ingressPointId, "ingressPointId is required");
        }

        @Override
        public final java.lang.String getIngressPointArn() {
            return this.ingressPointArn;
        }

        @Override
        public final java.lang.String getIngressPointId() {
            return this.ingressPointId;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("ingressPointArn", om.valueToTree(this.getIngressPointArn()));
            data.set("ingressPointId", om.valueToTree(this.getIngressPointId()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.interfaces.aws_ses.MailManagerIngressPointReference"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MailManagerIngressPointReference.Jsii$Proxy that = (MailManagerIngressPointReference.Jsii$Proxy) o;

            if (!ingressPointArn.equals(that.ingressPointArn)) return false;
            return this.ingressPointId.equals(that.ingressPointId);
        }

        @Override
        public final int hashCode() {
            int result = this.ingressPointArn.hashCode();
            result = 31 * result + (this.ingressPointId.hashCode());
            return result;
        }
    }
}
